==> sddm_0.11.0.orig.tar.gz: sddm-0.11.0/data/translations/fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Tervetuloa koneeseen %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Varoitus: Caps Lock on PÄÄLLÄ!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Asettelu</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Kirjautuminen epäonnistui</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Kirjautuminen onnistui</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Kirjoita käyttäjätunnuksesi ja salasanasi</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä uudelleen</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Istunto</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Valitse käyttäjä ja kirjoita salasana</translation>
    </message>
</context>
</TS>

==> sddm_0.19.0.orig.tar.gz: sddm-0.19.0/data/translations/fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Tervetuloa koneeseen %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Varoitus: Caps Lock on PÄÄLLÄ!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Asettelu</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Kirjautuminen epäonnistui</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Kirjautuminen onnistui</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Kirjoita käyttäjätunnuksesi ja salasanasi</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä uudelleen</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Istunto</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Valitse käyttäjä ja kirjoita salasana</translation>
    </message>
</context>
</TS>
